@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2005-2008 Zope Corporation and Contributors.
+# Copyright (c) 2005-2008 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -32,7 +32,7 @@ class Server:
     def __init__(self, connection):
         connection = zc.ngi.adapters.Lines(connection)
         self.connection = connection
-        connection.setHandler(self)
+        connection.set_handler(self)
         self.mode = QUIT_MARKER
 
     def handle_input(self, connection, data):
@@ -69,37 +69,54 @@ class Server:
     def handle_close(self, connection, reason):
         pass                            # Don't care
 
+#testing support
+last_listener = None
 
-def start(port):
+def start(address):
     """start monitor server.
-    
-    Returns True if monitor server started; returns False if the port is
-    already in use; and raises an exception otherwise.
+
+    Returns the listener address (which may be different from the
+    given address) if monitor server started; returns False if the
+    port is already in use; and raises an exception otherwise.
     """
     import zc.ngi.async
+
+    ourAddress = None
+    if isinstance(address, int):
+        #a port is passed as int
+        ourAddress = ('', address)
+    elif isinstance(address, tuple):
+        #an (address, port) tuple is passed
+        ourAddress = address
+    elif isinstance(address, basestring):
+        #a unix domain socket string is passed
+        ourAddress = address
+
     try:
-        zc.ngi.async.listener(('', port), Server)
+        global last_listener
+        last_listener = zc.ngi.async.listener(ourAddress, Server)
     except socket.error, e:
         if e.args[0] == errno.EADDRINUSE:
             # Don't kill the process just because somebody else has our port.
             # This might be a zopectl debug or some other innocuous problem.
             logging.warning(
-                'unable to start zc.monitor server because port %d is in use.',
-                port)
+                'unable to start zc.monitor server because the address %s '\
+                'is in use.',
+                ourAddress)
             return False
         else:
             raise
-    return True
+    return last_listener.address
 
 # default commands
 
 def interactive(connection):
     """Turn on monitor's interactive mode
-    
+
     Normally, the monitor releases the connection after a single command.
     By entering the interactive mode, the monitor will not end the connection
     until you enter the "quit" command.
-    
+
     In interactive mode, an empty line repeats the last command.
     """
     connection.write('Interactive mode on.  Use "quit" To exit.\n')
@@ -107,7 +124,7 @@ def interactive(connection):
 
 def quit(connection):
     """Quit the monitor
-    
+
     This is only really useful in interactive mode (see the "interactive"
     command).
     """
