@@ -1,10 +1,10 @@
 ##############################################################################
 #
-# Copyright (c) 2004-2008 Zope Corporation and Contributors.
+# Copyright (c) 2004-2008 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
-# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
@@ -12,7 +12,7 @@
 #
 ##############################################################################
 
-from zope.testing import doctest
+import doctest
 
 def test_suite():
     return doctest.DocFileSuite(
